## Filters

Filters process glyph layers.
Their functionality ranges from simple width transformations to randomized distortions of glyph outlines.
Glyphs includes a list of built-in filters.

Install additional filters from the Plugin Manager.
These filters are also listed in the “Filter” menu and applicable as custom parameters.